package jugs.javafx.b_properties;

import javafx.application.Application;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.ListView;
import javafx.scene.layout.GridPane;
import javafx.scene.paint.Color;
import javafx.stage.Stage;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class Exercise4_ColumnConfigObservableListExample extends Application
{
    @Override
    public void start(final Stage primaryStage)
    {
        final Label candidatesLbl = new Label("Available Columns");
        final Label heroesLbl = new Label("Columns");

        final ObservableList<String> availableColumns = FXCollections.observableArrayList("Geschlecht", "Col 1",
                                                                                          "Col 2", "Col 3");
        final ObservableList<String> configuredColumns = FXCollections.observableArrayList("Vorname", "Name", "Alter",
                                                                                           "Beruf");
        final ListView<String> leftListView = createListView(availableColumns);
        final ListView<String> rightListView = createListView(configuredColumns);
        
        final Button sendRightButton = new Button(">");
        sendRightButton.setOnAction(event -> transferColumn(leftListView, availableColumns, configuredColumns));
        final Button sendLeftButton = new Button("<");
        sendLeftButton.setOnAction(event -> transferColumn(rightListView, configuredColumns, availableColumns));
        
        // POSITIONIERUNG IM GRID
        final GridPane gridpane = new GridPane();
        gridpane.setPadding(new Insets(5));
        gridpane.setHgap(10);
        gridpane.setVgap(10);
        
        gridpane.add(candidatesLbl, 0, 0);
        gridpane.add(heroesLbl, 2, 0);
        gridpane.add(leftListView, 0, 1, 1, 7);
        gridpane.add(sendRightButton, 1, 1);
        gridpane.add(sendLeftButton, 1, 2);
        gridpane.add(rightListView, 2, 1, 1, 7);

        primaryStage.setScene(new Scene(gridpane, 300, 200, Color.WHITE));
        primaryStage.setTitle("ColumnConfigObservableListExample");
        primaryStage.show();
    }

    private ListView<String> createListView(final ObservableList<String> content)
    {
        final ListView<String> listView = new ListView<String>(content);
        listView.setPrefWidth(100);
        return listView;
    }

    private void transferColumn(final ListView<String> currentLstView, 
                                final ObservableList<String> from,
                                final ObservableList<String> to)
    {
        final String item = currentLstView.getSelectionModel().getSelectedItem();
        if (item != null)
        {
            currentLstView.getSelectionModel().clearSelection();
            from.remove(item);
            to.add(item);
        }
    }

    public static void main(final String[] args)
    {
        launch(args);
    }
}