package jugs.javafx.c_tables;

import java.time.LocalDate;
import java.util.Date;

import javafx.application.Application;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.TableColumn;
import javafx.scene.control.TableView;
import javafx.scene.control.cell.PropertyValueFactory;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class Exercise2_TableViewExample extends Application
{
    @Override
    public void start(final Stage stage)
    {
        final PersonEx[] persons = { new PersonEx("Duke", "Java", Gender.MALE, LocalDate.of(11, 2, 3)),
                        new PersonEx("DukeFX", "JavaFX", Gender.FEMALE, LocalDate.of(12, 5, 5)),
                        new PersonEx("Mike", "Indi", Gender.MALE, LocalDate.of(1971, 2, 7)),
                        new PersonEx("Lili", "Lila", Gender.FEMALE, LocalDate.of(1, 12, 23)),

                        new PersonEx("Mike", "Indi", Gender.MALE, LocalDate.of(1, 7, 2)),
                        new PersonEx("Tim", "Bötzi", Gender.MALE, LocalDate.of(1971, 3, 26)) };
        
        final ObservableList<PersonEx> data = FXCollections.observableArrayList(persons);
        
        final VBox root = new VBox(7);
        root.setPadding(new Insets(7, 7, 7, 7));
        root.getChildren().add(createTableView(data));
        
        stage.setScene(new Scene(root, 400, 300));
        stage.setTitle("TableViewExample");
        stage.show();
    }

    public TableView<PersonEx> createTableView(final ObservableList<PersonEx> data)
    {
        // create table view and columns
        final TableView<PersonEx> tableView = new TableView<PersonEx>();
        final TableColumn<PersonEx, String> firstNameCol = new TableColumn<>("Firstname");
        final TableColumn<PersonEx, String> lastNameCol = new TableColumn<>("Lastname");
        final TableColumn<PersonEx, Gender> genderCol = new TableColumn<>("Gender");
        final TableColumn<PersonEx, Date> birthdayCol = new TableColumn<>("Birthday");
        tableView.getColumns().addAll(firstNameCol, lastNameCol, genderCol, birthdayCol);

        // Data Bindung in Analogie zum TableModel von Swing
        // fragile Verbindung auf Strings basierend ... 
        firstNameCol.setCellValueFactory(new PropertyValueFactory<PersonEx, String>("firstName"));
        lastNameCol.setCellValueFactory(new PropertyValueFactory<PersonEx, String>("lastName"));
        genderCol.setCellValueFactory(new PropertyValueFactory<PersonEx, Gender>("gender"));
        birthdayCol.setCellValueFactory(new PropertyValueFactory<PersonEx, Date>("birthday"));

        genderCol.setCellFactory(new GenderOwnRenderer());
        
        tableView.setItems(data);
        return tableView;
    }

    public static void main(String[] args)
    {
        launch(Exercise2_TableViewExample.class, args);
    }
}
