package jugs.javafx.zusatz2_3D;

import javafx.animation.RotateTransition;
import javafx.animation.TranslateTransition;
import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.scene.Group;
import javafx.scene.Node;
import javafx.scene.PerspectiveCamera;
import javafx.scene.PointLight;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.paint.Color;
import javafx.scene.paint.PhongMaterial;
import javafx.scene.shape.Box;
import javafx.scene.shape.Sphere;
import javafx.scene.transform.Rotate;
import javafx.stage.Stage;
import javafx.util.Duration;

/**
 * Beispielprogramm für JavaFX-Schulung
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class SphereAndBox1 extends Application
{

    double anchorX, anchorY, anchorAngle;

    private PerspectiveCamera addCamera(Scene scene)
    {
        PerspectiveCamera perspectiveCamera = new PerspectiveCamera();
        scene.setCamera(perspectiveCamera);
        return perspectiveCamera;
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args)
    {
        // Remove this line once dirtyopts bug is fixed for 3D primitive
        System.setProperty("prism.dirtyopts", "false");
        launch(args);
    }

    @Override
    public void start(Stage primaryStage)
    {
        primaryStage.setTitle("SphereAndBox Rotation");

        final PhongMaterial redMaterial = new PhongMaterial();
        redMaterial.setSpecularColor(Color.ORANGE);
        redMaterial.setDiffuseColor(Color.RED);

        final PhongMaterial blueMaterial = new PhongMaterial();
        blueMaterial.setDiffuseColor(Color.BLUE);
        blueMaterial.setSpecularColor(Color.LIGHTBLUE);

        final Box red = new Box(400, 400, 200);
        red.setMaterial(redMaterial);

        final Sphere blue = new Sphere(200);
        blue.setMaterial(blueMaterial);

        blue.setTranslateX(350);
        blue.setTranslateY(350);
        blue.setTranslateZ(150);

        red.setTranslateX(100);
        red.setTranslateY(150);
        red.setTranslateZ(500);

        final Node buttonNode = new Button("Start Z Movement + Rotation");

        // Gruppieren und etwas nach hinten versetzen
        final Group parent = new Group(red, blue);
        parent.setTranslateZ(100);
        parent.setRotationAxis(Rotate.Y_AXIS);

        // Ereignisverarbeitung
        buttonNode.addEventHandler(ActionEvent.ACTION, new EventHandler<ActionEvent>()
        {

            @Override
            public void handle(final ActionEvent event)
            {

                // Transition separat definieren
                final TranslateTransition translateTransition = new TranslateTransition(Duration.millis(2000), parent);
                translateTransition.setFromZ(100);
                translateTransition.setToZ(700);
                translateTransition.setCycleCount(4);
                translateTransition.setAutoReverse(true);
                translateTransition.play();

                final RotateTransition rotateTransition = new RotateTransition(Duration.millis(8_000));
                rotateTransition.setNode(parent);
                rotateTransition.setByAngle(360);
                rotateTransition.setAutoReverse(true);
                rotateTransition.playFromStart();
            }
        });

        final Group root = new Group(parent, buttonNode);

        final Scene scene = new Scene(root, 500, 500, true);

        PointLight pointLight = new PointLight(Color.ANTIQUEWHITE);
        pointLight.setTranslateX(15);
        pointLight.setTranslateY(-10);
        pointLight.setTranslateZ(-100);

        PointLight pointLight2 = new PointLight(Color.ANTIQUEWHITE);
        pointLight2.setTranslateX(1000);
        pointLight2.setTranslateY(700);
        pointLight2.setTranslateZ(-100);

        root.getChildren().add(pointLight);
        root.getChildren().add(pointLight2);

        addCamera(scene);
        primaryStage.setScene(scene);
        primaryStage.show();
    }
}