package jugs.javafx.zusatz2_3D;

/**
 * Beispielprogramm für JavaFX-Schulung
 * 
 * @author Michael Inden Copyright 2015 by Michael Inden
 */
import javafx.application.Application;
import javafx.geometry.Point3D;
import javafx.scene.AmbientLight;
import javafx.scene.Group;
import javafx.scene.PerspectiveCamera;
import javafx.scene.PointLight;
import javafx.scene.Scene;
import javafx.scene.image.Image;
import javafx.scene.paint.Color;
import javafx.scene.paint.PhongMaterial;
import javafx.scene.shape.Box;
import javafx.scene.shape.Sphere;
import javafx.scene.transform.Rotate;
import javafx.stage.Stage;

public class SphereAndBox2 extends Application
{

    double anchorX, anchorY, anchorAngle1, anchorAngle2;

    public static void main(String[] args)
    {
        launch(args);
    }

    @Override
    public void start(Stage primaryStage)
    {
        primaryStage.setTitle("SphereAndBox");

        final PhongMaterial redMaterial = new PhongMaterial();
        redMaterial.setSpecularColor(Color.ORANGE);
        redMaterial.setDiffuseColor(Color.RED);

        final PhongMaterial blueMaterial = new PhongMaterial();
        blueMaterial.setDiffuseColor(Color.BLUE);
        blueMaterial.setSpecularColor(Color.LIGHTBLUE);

        final Box red = new Box(400, 400, 200);
        red.setMaterial(redMaterial);

        red.setTranslateX(150);
        red.setTranslateY(150);
        red.setTranslateZ(450);

        final Sphere blue = new Sphere(400);
        blue.setTranslateX(350);
        blue.setTranslateY(350);
        blue.setTranslateZ(50);

        final Group parent = new Group(red, blue);
        parent.setTranslateZ(500);
        parent.setRotationAxis(Rotate.Y_AXIS);

        // http://www.celestiamotherlode.net/catalog/earth.php

        // Create material
        PhongMaterial mat2 = new PhongMaterial();
        // bestimmt die Oberfl�che
        Image diffuseMap2 = new Image(this.getClass().getResourceAsStream("earth.png"));
        // bestimmt die Helligkeit
        Image bumpMap2 = new Image(this.getClass().getResourceAsStream("earthnormal.png"));

        // Set material properties
        mat2.setDiffuseMap(diffuseMap2);
        mat2.setBumpMap(bumpMap2);
        mat2.setSpecularColor(Color.WHITE);

        // Use the material for a shape
        blue.setMaterial(mat2);

        final Group root = new Group(parent);

        final Scene scene = new Scene(root, 700, 700, true);

        scene.setOnMousePressed(event -> {
            anchorX = event.getSceneX();
            anchorY = event.getSceneY();
            anchorAngle1 = parent.getRotate();
            anchorAngle2 = blue.getRotate();
        });

        scene.setOnMouseDragged(event -> {
            parent.setRotationAxis(new Point3D(0, 1, 0));
            parent.setRotate(anchorAngle1 + anchorX - event.getSceneX());
            blue.setRotationAxis(new Point3D(0, 0, 1));
            blue.setRotate(anchorAngle2 + anchorY - event.getSceneY());
        });

        PointLight pointLight = new PointLight(Color.ANTIQUEWHITE);
        pointLight.setTranslateX(-30);
        pointLight.setTranslateY(-30);
        pointLight.setTranslateZ(-100);

        AmbientLight light = new AmbientLight();
        light.setTranslateX(0);
        light.setTranslateY(00);
        light.setTranslateZ(-200);

        root.getChildren().add(pointLight);
        root.getChildren().add(light);

        addCamera(scene);
        primaryStage.setScene(scene);
        primaryStage.show();
    }

    private PerspectiveCamera addCamera(Scene scene)
    {
        PerspectiveCamera perspectiveCamera = new PerspectiveCamera();
        scene.setCamera(perspectiveCamera);
        return perspectiveCamera;
    }

}